@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.36.0", __name__, "aws-kms@0.36.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "0.36.1", __name__, "aws-kms@0.36.1.jsii.tgz")
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[])
 class AliasAttributes(jsii.compat.TypedDict):
     """
@@ -464,7 +464,7 @@ class IAlias(aws_cdk.core.IResource, jsii.compat.Protocol):
         Stability:
             experimental
         attribute:
-            AliasName
+            true
         """
         ...
 
@@ -476,7 +476,7 @@ class IAlias(aws_cdk.core.IResource, jsii.compat.Protocol):
         Stability:
             experimental
         attribute:
-            TargetKeyId
+            true
         """
         ...
 
@@ -496,7 +496,7 @@ class _IAliasProxy(jsii.proxy_for(aws_cdk.core.IResource)):
         Stability:
             experimental
         attribute:
-            AliasName
+            true
         """
         return jsii.get(self, "aliasName")
 
@@ -508,7 +508,7 @@ class _IAliasProxy(jsii.proxy_for(aws_cdk.core.IResource)):
         Stability:
             experimental
         attribute:
-            TargetKeyId
+            true
         """
         return jsii.get(self, "aliasTargetKey")
 
